@@ -13,6 +13,11 @@ import aws_cdk.aws_iam
 import aws_cdk.aws_kms
 import aws_cdk.core
 import constructs
-__all__ = []
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-sqs", "1.36.1", __name__[0:-6], "aws-sqs@1.36.1.jsii.tgz")
+
+__all__ = [
+    "__jsii_assembly__",
+]
 
 publication.publish()
